@@ -22,7 +22,7 @@ package MongoDB::Error;
 # ABSTRACT: MongoDB Driver Error classes
 
 use version;
-our $VERSION = 'v0.999.999.2'; # TRIAL
+our $VERSION = 'v0.999.999.3'; # TRIAL
 
 use Moose;
 use Carp;
@@ -272,7 +272,7 @@ MongoDB::Error - MongoDB Driver Error classes
 
 =head1 VERSION
 
-version v0.999.999.2
+version v0.999.999.3
 
 =head1 SYNOPSIS
 
@@ -304,7 +304,7 @@ are recommended:
         $coll->insert( $doc )
     }
     catch {
-        if ( $_->$_isa("MongoDB::DuplicateKeyError" ) {
+        if ( $_->$_isa("MongoDB::DuplicateKeyError" ) ) {
             ...
         }
         else {
