@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.999.2'; # TRIAL
+our $VERSION = 'v0.999.999.3'; # TRIAL
 
 use Moose;
 use MongoDB;
@@ -40,7 +40,7 @@ use Tie::IxHash;
 use Time::HiRes qw/usleep/;
 use Carp 'carp', 'croak';
 use Safe::Isa;
-use Scalar::Util 'reftype';
+use Scalar::Util qw/reftype weaken/;
 use Syntax::Keyword::Junction 'any';
 use boolean;
 use Encode;
@@ -189,17 +189,9 @@ has bson_codec => (
 sub _build_bson_codec {
     my ($self) = @_;
     return MongoDB::BSON->new(
-        dbref_callback => sub {
-            my $doc = shift;
-            return MongoDB::DBRef->new(
-                client => $self,
-                ref    => $doc->{'$ref'},
-                id     => $doc->{'$id'},
-                db     => $doc->{'$db'},
-            );
-        },
-        dt_type         => $self->dt_type,
-        prefer_numeric  => $MongoDB::BSON::looks_like_number || 0,
+        dbref_callback => sub { return MongoDB::DBRef->new(shift) },
+        dt_type        => $self->dt_type,
+        prefer_numeric => $MongoDB::BSON::looks_like_number || 0,
         ( $MongoDB::BSON::char ne '$' ? ( op_char => $MongoDB::BSON::char ) : () ),
     );
 }
@@ -1352,8 +1344,9 @@ sub database_names {
             }
             return 1;
         } catch {
-            # can't open db in a read lock
-            return if $_->result->ouput->{code} == CANT_OPEN_DB_IN_READ_LOCK() || $try < $max_tries;
+            if ( $_->$_isa("MongoDB::DatabaseError" ) ) {
+                return if $_->result->output->{code} == CANT_OPEN_DB_IN_READ_LOCK() || $try < $max_tries;
+            }
             die $_;
         };
     }
@@ -1482,7 +1475,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.999.2
+version v0.999.999.3
 
 =head1 SYNOPSIS
 
