@@ -19,7 +19,7 @@ package MongoDB::_Types;
 # MongoDB Moose type definitions
 
 use version;
-our $VERSION = 'v0.999.999.2'; # TRIAL
+our $VERSION = 'v0.999.999.3'; # TRIAL
 
 use Type::Library
   -base,
@@ -95,10 +95,6 @@ declare ConnectionStr, as Str,
 
 enum CursorType, [qw/non_tailable tailable tailable_await/];
 
-declare DBRefColl, as Str;
-
-declare DBRefDB, as Str;
-
 declare ErrorStr, as Str, where { $_ }; # needs a true value
 
 declare HashLike, as Ref, where { reftype($_) eq 'HASH' };
@@ -152,6 +148,10 @@ class_type WriteConcern, { class => 'MongoDB::WriteConcern' };
 # after SingleKeyHash and IxHash
 declare OrderedDoc, as ArrayRef|IxHash|SingleKeyHash;
 
+# after NonEmptyStr
+declare DBRefColl, as NonEmptyStr;
+declare DBRefDB, as NonEmptyStr|Undef;
+
 #--------------------------------------------------------------------------#
 # Coercions
 #--------------------------------------------------------------------------#
