@@ -29,7 +29,7 @@
 #    ifdef __hpux
 #        define Strtoll __strtoll
 #    endif
-#    ifdef WIN64
+#    ifdef WIN32
 #        define Strtoll _strtoi64
 #    endif
 #    if !defined(Strtoll) && defined(HAS_STRTOLL)
@@ -1143,10 +1143,9 @@ bson_doc_to_hashref(bson_iter_t * iter, HV *opts) {
 
     key_num++;
     /* check if this is a DBref. We must see the keys
-       $ref, $id, and $db in that order, with no extra keys */
+       $ref, $id, and optionally $db in that order, with no extra keys */
     if ( key_num == 1 && strcmp( name, "$ref" ) ) is_dbref = 0;
     if ( key_num == 2 && is_dbref == 1 && strcmp( name, "$id" ) ) is_dbref = 0;
-    if ( key_num == 3 && is_dbref == 1 && strcmp( name, "$db" ) ) is_dbref = 0;
 
     /* get value and store into hash */
     value = bson_elem_to_sv(iter, opts);
@@ -1158,7 +1157,7 @@ bson_doc_to_hashref(bson_iter_t * iter, HV *opts) {
   ret = newRV_noinc ((SV *)hv);
 
   /* XXX shouldn't need to limit to size 3 */
-  if ( key_num == 3 && is_dbref == 1
+  if ( key_num >= 2 && is_dbref == 1
       && (cb = _hv_fetchs_sv(opts, "dbref_callback")) && SvOK(cb)
   ) {
     SV *dbref = call_sv_va(cb, 1, ret);
