@@ -24,10 +24,11 @@ use warnings;
 use Exporter 'import';
 use MongoDB;
 use Test::More;
+use boolean;
 use version;
 
 our @EXPORT_OK = qw(
-  build_client get_test_db server_version server_type clear_testdbs
+  build_client get_test_db server_version server_type clear_testdbs get_capped
 );
 
 my @testdbs;
@@ -45,7 +46,6 @@ sub build_client {
         $host,
         {
             ssl                         => $ENV{MONGO_SSL},
-            find_master                 => 1,
             query_timeout               => 60000,
             server_selection_timeout_ms => 1000,
             %args,
@@ -62,6 +62,13 @@ sub get_test_db {
     return  $db;
 }
 
+sub get_capped {
+    my ($db, $name, %args) = @_;
+    $name ||= 'capped' . int(rand(2**31));
+    $args{size} ||= 500_000;
+    $db->run_command([ create => $name, capped => true, %args ]);
+    return $db->get_collection($name);
+}
 
 # XXX eventually, should move away from this and towards a fixture object instead
 BEGIN {
@@ -88,7 +95,7 @@ BEGIN {
 sub server_version {
 
     my $conn = shift;
-    my $build = $conn->get_database( 'admin' )->get_collection( '$cmd' )->find_one( { buildInfo => 1 } );
+    my $build = $conn->send_admin_command( [ buildInfo => 1 ] )->output;
     my ($version_str) = $build->{version} =~ m{^([0-9.]+)};
     return version->parse("v$version_str");
 }
